# Chart Semirings

Semiring abstractions for parameterizing chart parsing (Goodman, 1999). Different semirings yield different parsing algorithms from the same CKY skeleton: marginal log-probability, Viterbi best-parse, boolean recognition, or derivation counting.

::: quivers.stochastic.semiring
